@@ -8,19 +8,19 @@ use warnings;
 use Params::Util   1.00 ();
 use ORLite::Mirror 1.18 ();
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 sub import {
 	my $class = shift;
-	my $params = Params::Util::_HASH(shift) || {};
+	my $param = Params::Util::_HASH(shift) || {};
 
 	# Pass through any params from above
-	$params->{url}    ||= 'http://rt.cpan.org/NoAuth/cpan/rtcpan.sqlite.gz';
-	$params->{maxage} ||= 24 * 60 * 60; # One day
+	$param->{url}    ||= 'http://rt.cpan.org/NoAuth/cpan/rtcpan.sqlite.gz';
+	$param->{maxage} ||= 24 * 60 * 60; # One day
 
 	# Prevent double-initialisation
 	$class->can('orlite') or
-	ORLite::Mirror->import( $params );
+	ORLite::Mirror->import($param);
 
 	return 1;
 }
